@@ -23,6 +23,10 @@ from qtpy.QtGui import QTextCursor
 # Local imports
 from spyder.config.base import running_in_ci, running_in_ci_with_conda
 from spyder.config.utils import is_anaconda
+from spyder.plugins.completion.api import (
+    CompletionRequestTypes, CompletionItemKind)
+from spyder.plugins.completion.providers.languageserver.providers.utils import (
+    path_as_uri)
 from spyder.plugins.completion.providers.kite.utils.status import (
     check_if_kite_installed, check_if_kite_running)
 from spyder.py3compat import PY2
@@ -1178,5 +1182,177 @@ def test_completions_environment(completions_codeeditor, qtbot, tmpdir):
     completion_plugin.after_configuration_update([])
 
 
+@pytest.mark.slow
+@pytest.mark.order(1)
+@flaky(max_runs=5)
+def test_dot_completions(completions_codeeditor, qtbot):
+    """
+    Test that completions after a dot are working as expected.
+
+    This is a regression test for issue spyder-ide/spyder#20285
+    """
+    code_editor, _ = completions_codeeditor
+    completion = code_editor.completion_widget
+    code_editor.toggle_code_snippets(False)
+
+    # Import module and check completions are shown for it after writing a dot
+    # after it
+    qtbot.keyClicks(code_editor, "import math")
+    qtbot.keyPress(code_editor, Qt.Key_Enter)
+
+    qtbot.wait(500)
+    assert not completion.isVisible()
+
+    with qtbot.waitSignal(completion.sig_show_completions, timeout=10000):
+        qtbot.keyClicks(code_editor, "math.")
+
+    qtbot.wait(500)
+    assert completion.isVisible()
+
+    # Select a random entry in the completion widget
+    entry_index = random.randint(0, 30)
+    inserted_entry = completion.completion_list[entry_index]['insertText']
+    for _ in range(entry_index):
+        qtbot.keyPress(completion, Qt.Key_Down, delay=50)
+
+    # Insert completion and check that the inserted text is the expected one
+    qtbot.keyPress(completion, Qt.Key_Enter)
+    qtbot.wait(500)
+    assert code_editor.toPlainText() == f'import math\nmath.{inserted_entry}'
+
+
+@pytest.mark.slow
+@pytest.mark.order(1)
+@pytest.mark.parametrize(
+    "filename", ['000_test.txt', '.hidden', 'any_file.txt', 'abc.py',
+                 'part.0.parquet'])
+def test_file_completions(filename, mock_completions_codeeditor, qtbot):
+    """
+    Test that completions for files are handled as expected.
+
+    This includes a regression test for issue spyder-ide/spyder#20156
+    """
+    code_editor, mock_response = mock_completions_codeeditor
+    completion = code_editor.completion_widget
+
+    # Set text to complete and move cursor to the position we want to ask for
+    # completions.
+    if filename == 'any_file.txt':
+        # This checks if we're able to introduce file completions as expected
+        # for any file when requesting them inside a string.
+        qtbot.keyClicks(code_editor, "''")
+    elif filename == 'abc.py':
+        # This checks that we can insert file completions correctly after a
+        # dot
+        qtbot.keyClicks(code_editor, "'abc.'")
+    elif filename == 'part.0.parquet':
+        # This checks that we can insert file completions next to a dot when a
+        # filename has several dots.
+        qtbot.keyClicks(code_editor, "'part.0.'")
+    else:
+        qtbot.keyClicks(code_editor, f"'{filename[0]}'")
+    code_editor.moveCursor(QTextCursor.PreviousCharacter)
+    qtbot.wait(500)
+
+    mock_response.side_effect = lambda lang, method, params: {'params': [{
+        'label': f'{filename}',
+        'kind': CompletionItemKind.FILE,
+        'sortText': (0, f'a{filename}'),
+        'insertText': f'{filename}',
+        'data': {'doc_uri': path_as_uri(__file__)},
+        'detail': '',
+        'documentation': '',
+        'filterText': f'{filename}',
+        'insertTextFormat': 1,
+        'provider': 'LSP',
+        'resolve': True
+    }]} if method == CompletionRequestTypes.DOCUMENT_COMPLETION else None
+
+    with qtbot.waitSignal(completion.sig_show_completions,
+                          timeout=10000):
+        qtbot.keyPress(code_editor, Qt.Key_Tab, delay=300)
+
+    qtbot.wait(500)
+    assert code_editor.get_text_with_eol() == f"'{filename}'"
+
+
+@pytest.mark.slow
+@pytest.mark.order(1)
+@pytest.mark.parametrize(
+    "directory",
+    [
+         pytest.param(
+             '/home',
+             marks=pytest.mark.skipif(
+                 not sys.platform.startswith('linux'),
+                 reason='Only works on Linux'
+             )
+        ),
+        pytest.param(
+            'C:\\Users',
+            marks=pytest.mark.skipif(
+                not os.name == 'nt',
+                reason='Only works on Windows'
+            )
+        ),
+        pytest.param(
+            'C:\\Windows\\System32',
+            marks=pytest.mark.skipif(
+                not os.name == 'nt',
+                reason='Only works on Windows'
+            )
+        ),
+        pytest.param(
+            '/Library/Frameworks',
+            marks=pytest.mark.skipif(
+                not sys.platform == 'darwin',
+                reason='Only works on macOS'
+            )
+        )
+    ]
+)
+def test_directory_completions(directory, completions_codeeditor, qtbot):
+    """
+    Test that directory completions work as expected.
+    """
+    code_editor, _ = completions_codeeditor
+    completion = code_editor.completion_widget
+
+    qtbot.wait(500)
+    assert not completion.isVisible()
+
+    if directory == '/home':
+        qtbot.keyClicks(code_editor, "'/'")
+    elif directory == 'C:\\Users':
+        qtbot.keyClicks(code_editor, r"'C:\\'")
+    elif directory == 'C:\\Windows\\System32':
+        qtbot.keyClicks(code_editor, r"'C:\\Windows\\'")
+    else:
+        qtbot.keyClicks(code_editor, "'/Library/'")
+
+    code_editor.moveCursor(QTextCursor.PreviousCharacter)
+    with qtbot.waitSignal(completion.sig_show_completions,
+                          timeout=10000):
+        qtbot.keyPress(code_editor, Qt.Key_Tab, delay=300)
+
+    qtbot.wait(500)
+    assert completion.isVisible()
+
+    # Select the corresponding entry in the completion widget
+    selected_entry = False
+    while not selected_entry:
+        item = completion.currentItem()
+        label = item.data(Qt.AccessibleTextRole).split()[0]
+        if directory.split(os.sep)[-1] in label:
+            selected_entry = True
+        else:
+            qtbot.keyPress(completion, Qt.Key_Down, delay=50)
+
+    # Insert completion and check that the inserted text is the expected one
+    qtbot.keyPress(completion, Qt.Key_Enter)
+    qtbot.wait(500)
+    assert osp.normpath(code_editor.toPlainText()) == f"'{directory}{os.sep}'"
+
+
 if __name__ == '__main__':
     pytest.main(['test_introspection.py', '--run-slow'])
